==> amarok-2.2.2.90.tar.bz2: amarok-2.2.2.90/tests/TestCaseConverter.h <==
/***************************************************************************
 *   Copyright (c) 2009 Sven Krohlas <sven@getamarok.com>                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef TESTCASECONVERTER_H
#define TESTCASECONVERTER_H

#include "TestBase.h"

#include <QtCore/QObject>

class TestCaseConverter : public TestBase
{
Q_OBJECT

public:
    TestCaseConverter( const QStringList args, const QString &logPath );

private slots:
    void testToCapitalizedCase();
    void testToTitleCase();
};

#endif // TESTCASECONVERTER_H

==> amarok-2.3.2.tar.bz2: amarok-2.3.2/tests/TestCaseConverter.h <==
/***************************************************************************
 *   Copyright (c) 2009 Sven Krohlas <sven@getamarok.com>                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#ifndef TESTCASECONVERTER_H
#define TESTCASECONVERTER_H

#include <QtCore/QObject>

class TestCaseConverter : public QObject
{
Q_OBJECT

public:
    TestCaseConverter();

private slots:
    void testToCapitalizedCase();
    void testToTitleCase();
};

#endif // TESTCASECONVERTER_H
